% MAKE_TF_CORR_PLOTS(ALL_TARGETS, SR, NUM_SUB, NUM_WIN, LOW_LIM, HI_LIM, WIN_MS)
%
% this script generates correlation functions for time at different
% frequencies, and for frequency at different times
%
% this version calculates this for the experimental stimuli (consistency
% check)
% 
% example:
%
% dur_ms = 320; win_ms = 20; num_win = round(dur_ms/10)-2; num_sub = 38;
% sr= 24000; low_lim = 20; hi_lim = 4300;
% [target_sounds, target_grids] = generate_gauss_sounds(40,dur_ms,1/.075,1/.065,.5,sr,1);
% make_tf_corr_plots(all_targets,sr,num_sub,num_win,low_lim,hi_lim,win_ms);
%

% June-19-2011 Josh McDermott


function make_tf_corr_plots(all_targets,sr,num_sub,num_win,low_lim,hi_lim,win_ms)

zp=1;
which_segment=1;
invgray = flipud(gray);

aud_threshold = -40;
log_const = 10^-12;

time_offsets = [1:num_win];
freq_offsets = [1:num_sub];
nt=length(time_offsets)+1;
nf=length(freq_offsets)+1;

temp_corr_n = zeros(1,nt);
freq_corr_n = zeros(1,nf);
temp_corr_sum = zeros(nt,num_sub+1);
freq_corr_sum = zeros(nf,nt);

avg_grid = zeros(38,32);

all_segments = [];
all_segments2 = [];
for file_num = [1:size(all_targets,1)]
    %file_num
    
    x1 = all_targets(file_num,:)';
    win_length = round(sr*win_ms/1000);
    if rem(win_length,2)==0
        win_length = win_length+1;
    end
    
    [E] = sound_energy_grid_full(x1,sr,num_sub-1,low_lim,hi_lim,win_ms,zp);
    mean_mag1 = 20*log10((E+log_const));
    L_t = size(E,2);
    L_f = num_sub; %+1 because leaving out highest subband
    
    avg_grid = avg_grid+mean_mag1;

    mean_mag1=mean_mag1'; %time indexes the rows
    if size(mean_mag1,1)>=nt
        if which_segment==1
            section_to_use = mean_mag1(1:nt,:); %ensures all are same size
        elseif which_segment==2
            section_to_use = mean_mag1(end-nt+1:end,:); %ensures all are same size
        elseif which_segment==3
            if rem(L_t,2)==0
                border = (L_t-nt)/2
                section_to_use = mean_mag1(border+1:border+nt,:);
            else
                border1 = floor((L_t-nt)/2);
                border2 = L_t-nt-border1;
                section_to_use = mean_mag1(border1+1:L_t-border2,:);
            end
        end
        segment_vector = reshape(section_to_use,prod(size(section_to_use)),1);
        segment_vector2 = reshape(section_to_use',prod(size(section_to_use)),1);
    else
        segment_vector=[];
    end
    if length(segment_vector)>0
        all_segments = [all_segments segment_vector];
        all_segments2 = [all_segments2 segment_vector2];
    end
end
avg_grid = avg_grid/size(all_targets,1);
targ_avg_grid=avg_grid;

clear temp_corr freq_corr
specgram_corr = corr(all_segments');
for f=1:L_f
    temp_corr(:,f) = corr_fn(specgram_corr((f-1)*nt+1:f*nt, (f-1)*nt+1:f*nt))';
end
temp_corr_avg = mean(temp_corr,2);
targ_temp_corr_avg = temp_corr_avg;

specgram_corr2 = corr(all_segments2');
for t=1:nt
    freq_corr(:,t) = corr_fn(specgram_corr2((t-1)*L_f+1:t*L_f, (t-1)*L_f+1:t*L_f))';
end
freq_corr_avg = mean(freq_corr,2);
targ_freq_corr_avg = freq_corr_avg;

figure;
subplot(2,1,1);
my_map = jet(L_f);
hold on;
for f = 1:L_f
    plot(10*([1:nt]-1),temp_corr(:,f),'Color',my_map(f,:))
end
plot(10*([1:nt]-1),temp_corr_avg,'k-o','LineWidth',2);
xlabel('Time Offset (ms)'); ylabel('Correlation Coefficient');
set(gca,'XLim',[0 310],'YLim',[-0.4 1]);
h = colorbar; ylabel(h,'Low <-- Frequency Subband --> High');
title('Experimental Stimuli Generated, Measured w Zero-Padding');

subplot(2,1,2);
my_map = jet(nt);
hold on;
for t = 1:nt
    plot([0:32],freq_corr(1:33,t),'Color',my_map(t,:))
end
plot([0:32],freq_corr_avg(1:33),'k-o','LineWidth',2)
xlabel('Subband Offset'); ylabel('Correlation Coefficient');
set(gca,'YLim',[-0.2 1]);
h = colorbar; ylabel(h,'Early <-- Time Point --> Later');

